==> zerochplus_0.6.1.tar.gz: zerochplus_0.6.1/test/module/legolas.pl <==
#============================================================================================================
#
#	wb_Etb^EMETAǗW[(LEGOLAS)
#	legolas.pl
#	--------------------------------------------------
#	2003.01.24 start
#	2003.02.04 Printǉ
#	2003.03.15 tb^Ǘǉ
#	2003.03.22 METAǗ
#
#============================================================================================================
package	LEGOLAS;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (@HEAD, $TEXT, $URL, $PATH, $FILE, $obj);
	
	undef @HEAD;
	$PATH = "";
	$FILE = "";
	
	$obj = {
		'HEAD'	=> \@HEAD,
		'TEXT'	=> $TEXT,
		'URL'	=> $URL,
		'PATH'	=> $PATH,
		'FILE'	=> $FILE
	};
	
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	wb_Etb^̓ǂݍ - Load
#	-------------------------------------------
#	@F$Sys    : W[
#			$kind : 
#	߂lF
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($Sys, $kind) = @_;
	my ($head, $path, $file);
	
	$path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS');
	if ($kind eq 'HEAD') { $file = 'head.txt'; }
	if ($kind eq 'FOOT') { $file = 'foot.txt'; }
	if ($kind eq 'META') { $file = 'meta.txt'; }
	
	$this->{'TEXT'} = $Sys->Get('HEADTEXT');
	$this->{'URL'} = $Sys->Get('HEADURL');
	$this->{'PATH'} = $path;
	$this->{'FILE'} = $file;
	
	$head = $this->{'HEAD'};
	
	if (-e "$path/$file") {
		open(HEAD, "< $path/$file");
		@$head = <HEAD>;
		close HEAD;
		return 0;
	}
	
	return -1;
}

#------------------------------------------------------------------------------------------------------------
#
#	wb_Etb^̏ - Save
#	-------------------------------------------
#	@F$Sys : W[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($Sys) = @_;
	my ($path, $file);
	
	$path = $this->{'PATH'};
	$file = $this->{'FILE'};
	
	if ($path) {
#		eval
		{
			chmod 0666, "$path/$file";
			open HEAD, "> $path/$file";
			flock HEAD, 2;
			print HEAD @{$this->{'HEAD'}};
			close HEAD;
			chmod $Sys->Get('PM-TXT'), "$path/$file";
		};
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	e̐ݒ - Set
#	-------------------------------------------
#	@F$head : ݒe
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($head) = @_;
	my @work;
	
	undef @{$this->{'HEAD'}};
	
	@work = split(/\n/, $$head);
	foreach (@work) {
		push @{$this->{'HEAD'}}, "$_\n";
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	e̎擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	e̎Q
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	
	return \@{$this->{'HEAD'}};
}

#------------------------------------------------------------------------------------------------------------
#
#	e̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	THORIN
#	@param	$Set	ISILDUR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Print
{
	my $this = shift;
	my ($Page, $Set) = @_;
	my ($bbs, $tcol, $text, $url);
	
	# head.txt̏ꍇ̓wb_SĂ\
	if ($this->{'FILE'} eq 'head.txt') {
		$bbs = $Set->Get('BBS_SUBTITLE');
		$tcol = $Set->Get('BBS_MENU_COLOR');
		$text = $this->{'TEXT'};
		$url = $this->{'URL'};
	
	$Page->Print(<<HEAD);
<a name="info"></a>
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="$tcol" style="margin-bottom:1.2em;" align="center">
 <tr>
  <td>
  <table border="0" width="100%">
   <tr>
    <td><font size="+1"><b>$bbs</b></font></td>
    <td align="right"><a href="#menu"></a> <a href="#1"></a></td>
   </tr>
   <tr>
    <td colspan="2">
HEAD
		
		foreach (@{$this->{'HEAD'}}) {
			$Page->Print("    $_");
		}
		
		$Page->Print("    </td>\n");
		$Page->Print("   </tr>\n");
		$Page->Print("  </table>\n");
		$Page->Print("  </td>\n");
		$Page->Print(" </tr>\n");
		
		if ($text ne "") {
			$Page->Print(" <tr>\n");
			$Page->Print("  <td align=\"center\"><a href=\"$url\" target=\"_blank\">$text</a></td>\n");
			$Page->Print(" </tr>\n");
		}
		
		$Page->Print("</table>\n\n");
		#$Page->Print("<br>\n");
	}
	# META.txt̓Cfg
	elsif ($this->{'FILE'} eq 'meta.txt') {
		foreach (@{$this->{'HEAD'}}) {
			$Page->Print(" $_");
		}
		$Page->Print("\n");
	}
	# ͓̑ê܂ܕ\
	else {
		foreach (@{$this->{'HEAD'}}) {
			$Page->Print("$_");
		}
	}
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;

==> zerochplus_0.7.2.tar.gz: zerochplus_0.7.2/test/module/legolas.pl <==
#============================================================================================================
#
#	wb_Etb^EMETAǗW[
#
#============================================================================================================
package	LEGOLAS;

use strict;
#use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $class = shift;
	
	my $obj = {
		'HEAD'	=> undef,
		'TEXT'	=> undef,
		'URL'	=> undef,
		'PATH'	=> undef,
		'FILE'	=> undef,
	};
	
	bless $obj, $class;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	wb_Etb^̓ǂݍ - Load
#	-------------------------------------------
#	@F$Sys    : W[
#			$kind : 
#	߂lFG[ԍ
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($Sys, $kind) = @_;
	
	my $path = $Sys->Get('BBSPATH') . '/' . $Sys->Get('BBS');
	my $file = '';
	$file = 'head.txt' if ($kind eq 'HEAD');
	$file = 'foot.txt' if ($kind eq 'FOOT');
	$file = 'meta.txt' if ($kind eq 'META');
	
	$this->{'TEXT'} = $Sys->Get('HEADTEXT');
	$this->{'URL'} = $Sys->Get('HEADURL');
	$this->{'PATH'} = $path;
	$this->{'FILE'} = $file;
	
	my $head = $this->{'HEAD'} = [];
	
	if (open(my $fh, '<', "$path/$file")) {
		flock($fh, 2);
		@$head = <$fh>;
		close($fh);
		return 0;
	}
	
	return -1;
}

#------------------------------------------------------------------------------------------------------------
#
#	wb_Etb^̏ - Save
#	-------------------------------------------
#	@F$Sys : MELKORW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($Sys) = @_;
	
	my $path = "$this->{'PATH'}/$this->{'FILE'}";
	
	if (open(my $fh, (-f $path ? '+<' : '>'), $path)) {
		flock($fh, 2);
		seek($fh, 0, 0);
		print $fh @{$this->{'HEAD'}};
		truncate($fh, tell($fh));
		close($fh);
	}
	else {
		warn "can't save header/footer: $path";
	}
	chmod($Sys->Get('PM-TXT'), $path);
}

#------------------------------------------------------------------------------------------------------------
#
#	e̐ݒ - Set
#	-------------------------------------------
#	@F$head : ݒe(t@X)
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($head) = @_;
	
	open(my $fh, '<', $head);
	my @lines = <$fh>;
	close $fh;
	$this->{'HEAD'} = \@lines;
}

#------------------------------------------------------------------------------------------------------------
#
#	e̎擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	e̎Q
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	
	return $this->{'HEAD'};
}

#------------------------------------------------------------------------------------------------------------
#
#	e̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	THORIN
#	@param	$Set	ISILDUR
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Print
{
	my $this = shift;
	my ($Page, $Set) = @_;
	
	# head.txt̏ꍇ̓wb_SĂ\
	if ($this->{'FILE'} eq 'head.txt') {
		my $bbs = $Set->Get('BBS_SUBTITLE');
		my $tcol = $Set->Get('BBS_MENU_COLOR');
		my $text = $this->{'TEXT'};
		my $url = $this->{'URL'};
	
	$Page->Print(<<HEAD);
<a name="info"></a>
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="$tcol" style="margin-bottom:1.2em;" align="center">
 <tr>
  <td>
  <table border="0" width="100%">
   <tr>
    <td><font size="+1"><b>$bbs</b></font></td>
    <td align="right"><a href="#menu"></a> <a href="#1"></a></td>
   </tr>
   <tr>
    <td colspan="2">
HEAD
		
		foreach (@{$this->{'HEAD'}}) {
			$Page->Print("    $_");
		}
		
		$Page->Print("    </td>\n");
		$Page->Print("   </tr>\n");
		$Page->Print("  </table>\n");
		$Page->Print("  </td>\n");
		$Page->Print(" </tr>\n");
		
		if ($text ne '') {
			$Page->Print(" <tr>\n");
			$Page->Print("  <td align=\"center\"><a href=\"$url\" target=\"_blank\">$text</a></td>\n");
			$Page->Print(" </tr>\n");
		}
		
		$Page->Print("</table>\n\n");
		#$Page->Print("<br>\n");
	}
	# META.txt̓Cfg
	elsif ($this->{'FILE'} eq 'meta.txt') {
		foreach (@{$this->{'HEAD'}}) {
			$Page->Print(" $_");
		}
		$Page->Print("\n");
	}
	# ͓̑ê܂ܕ\
	else {
		foreach (@{$this->{'HEAD'}}) {
			$Page->Print($_);
		}
	}
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;
